sqlobject.tests.test_enum module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_enum module

class `sqlobject.tests.test_enum.` `Enum1`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `cl`
  `j` = enum1
  `q` = enum1
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_enum.Enum1`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'enum1'

class `sqlobject.tests.test_enum.` `EnumUnicode`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `cl`
  `j` = enum_unicode
  property `n`
  `q` = enum_unicode
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_enum.EnumUnicode`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'enum_unicode'

class `sqlobject.tests.test_enum.` `EnumWithDefaultNone`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `cl`
  `j` = enum_with_default_none
  `q` = enum_with_default_none
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_enum.EnumWithDefaultNone`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'enum_with_default_none'

class `sqlobject.tests.test_enum.` `EnumWithDefaultOther`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `cl`
  `j` = enum_with_default_other
  `q` = enum_with_default_other
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_enum.EnumWithDefaultOther`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'enum_with_default_other'

class `sqlobject.tests.test_enum.` `EnumWithNone`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `cl`
  `j` = enum_with_none
  `q` = enum_with_none
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_enum.EnumWithNone`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'enum_with_none'

`sqlobject.tests.test_enum.` `testBad`()

`sqlobject.tests.test_enum.` `testDefaultNone`()

`sqlobject.tests.test_enum.` `testDefaultOther`()

`sqlobject.tests.test_enum.` `testNone`()

`sqlobject.tests.test_enum.` `testUnicode`()